package org.eclipse.jdt.internal.compiler.apt.util;

import java.util.StringTokenizer;
import java.util.HashSet;
import java.util.Set;

public final class Options
{
    private static final Set<String> ZERO_ARGUMENT_OPTIONS;
    private static final Set<String> ONE_ARGUMENT_OPTIONS;
    private static final Set<String> FILE_MANAGER_OPTIONS;
    
    static {
        (ZERO_ARGUMENT_OPTIONS = new HashSet()).add("-progress");
        Options.ZERO_ARGUMENT_OPTIONS.add("-proceedOnError");
        Options.ZERO_ARGUMENT_OPTIONS.add("-proceedOnError:Fatal");
        Options.ZERO_ARGUMENT_OPTIONS.add("-time");
        Options.ZERO_ARGUMENT_OPTIONS.add("-v");
        Options.ZERO_ARGUMENT_OPTIONS.add("-version");
        Options.ZERO_ARGUMENT_OPTIONS.add("-showversion");
        Options.ZERO_ARGUMENT_OPTIONS.add("-deprecation");
        Options.ZERO_ARGUMENT_OPTIONS.add("-help");
        Options.ZERO_ARGUMENT_OPTIONS.add("-?");
        Options.ZERO_ARGUMENT_OPTIONS.add("-help:warn");
        Options.ZERO_ARGUMENT_OPTIONS.add("-?:warn");
        Options.ZERO_ARGUMENT_OPTIONS.add("-noExit");
        Options.ZERO_ARGUMENT_OPTIONS.add("-verbose");
        Options.ZERO_ARGUMENT_OPTIONS.add("-referenceInfo");
        Options.ZERO_ARGUMENT_OPTIONS.add("-inlineJSR");
        Options.ZERO_ARGUMENT_OPTIONS.add("-g");
        Options.ZERO_ARGUMENT_OPTIONS.add("-g:none");
        Options.ZERO_ARGUMENT_OPTIONS.add("-warn:none");
        Options.ZERO_ARGUMENT_OPTIONS.add("-preserveAllLocals");
        Options.ZERO_ARGUMENT_OPTIONS.add("-enableJavadoc");
        Options.ZERO_ARGUMENT_OPTIONS.add("-Xemacs");
        Options.ZERO_ARGUMENT_OPTIONS.add("-X");
        Options.ZERO_ARGUMENT_OPTIONS.add("-O");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.3");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.4");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.5");
        Options.ZERO_ARGUMENT_OPTIONS.add("-5");
        Options.ZERO_ARGUMENT_OPTIONS.add("-5.0");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.6");
        Options.ZERO_ARGUMENT_OPTIONS.add("-6");
        Options.ZERO_ARGUMENT_OPTIONS.add("-6.0");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.7");
        Options.ZERO_ARGUMENT_OPTIONS.add("-7");
        Options.ZERO_ARGUMENT_OPTIONS.add("-7.0");
        Options.ZERO_ARGUMENT_OPTIONS.add("-1.8");
        Options.ZERO_ARGUMENT_OPTIONS.add("-8");
        Options.ZERO_ARGUMENT_OPTIONS.add("-8.0");
        Options.ZERO_ARGUMENT_OPTIONS.add("-proc:only");
        Options.ZERO_ARGUMENT_OPTIONS.add("-proc:none");
        Options.ZERO_ARGUMENT_OPTIONS.add("-XprintProcessorInfo");
        Options.ZERO_ARGUMENT_OPTIONS.add("-XprintRounds");
        Options.ZERO_ARGUMENT_OPTIONS.add("-parameters");
        Options.ZERO_ARGUMENT_OPTIONS.add("-genericsignature");
        (FILE_MANAGER_OPTIONS = new HashSet()).add("-bootclasspath");
        Options.FILE_MANAGER_OPTIONS.add("-encoding");
        Options.FILE_MANAGER_OPTIONS.add("-d");
        Options.FILE_MANAGER_OPTIONS.add("-classpath");
        Options.FILE_MANAGER_OPTIONS.add("-cp");
        Options.FILE_MANAGER_OPTIONS.add("-sourcepath");
        Options.FILE_MANAGER_OPTIONS.add("-extdirs");
        Options.FILE_MANAGER_OPTIONS.add("-endorseddirs");
        Options.FILE_MANAGER_OPTIONS.add("-s");
        Options.FILE_MANAGER_OPTIONS.add("-processorpath");
        (ONE_ARGUMENT_OPTIONS = new HashSet()).addAll(Options.FILE_MANAGER_OPTIONS);
        Options.ONE_ARGUMENT_OPTIONS.add("-log");
        Options.ONE_ARGUMENT_OPTIONS.add("-repeat");
        Options.ONE_ARGUMENT_OPTIONS.add("-maxProblems");
        Options.ONE_ARGUMENT_OPTIONS.add("-source");
        Options.ONE_ARGUMENT_OPTIONS.add("-target");
        Options.ONE_ARGUMENT_OPTIONS.add("-processor");
        Options.ONE_ARGUMENT_OPTIONS.add("-classNames");
        Options.ONE_ARGUMENT_OPTIONS.add("-properties");
    }
    
    public Options() {
    }
    
    public static int processOptionsFileManager(String option) {
        if (option == null) {
            return -1;
        }
        if (Options.FILE_MANAGER_OPTIONS.contains(option)) {
            return 1;
        }
        return -1;
    }
    
    public static int processOptions(String option) {
        if (option == null) {
            return -1;
        }
        if (Options.ZERO_ARGUMENT_OPTIONS.contains(option)) {
            return 0;
        }
        if (Options.ONE_ARGUMENT_OPTIONS.contains(option)) {
            return 1;
        }
        if (option.startsWith("-g")) {
            int length = option.length();
            if (length > 3) {
                StringTokenizer tokenizer2 = new StringTokenizer(option.substring(3, option.length()), ",");
                while (tokenizer2.hasMoreTokens()) {
                    String token2 = tokenizer2.nextToken();
                    if (!"vars".equals(token2) && !"lines".equals(token2)) {
                        if ("source".equals(token2)) {
                            continue;
                        }
                        return -1;
                    }
                    else {
                        continue;
                    }
                }
                return 0;
            }
            return -1;
        }
        else if (option.startsWith("-warn")) {
            int length = option.length();
            if (length <= 6) {
                return -1;
            }
            int warnTokenStart;
            switch (option.charAt(6)) {
                case '+': {
                    warnTokenStart = 7;
                    break;
                }
                case '-': {
                    warnTokenStart = 7;
                    break;
                }
                default: {
                    warnTokenStart = 6;
                    break;
                }
            }
            StringTokenizer tokenizer = new StringTokenizer(option.substring(warnTokenStart, option.length()), ",");
            int tokenCounter = 0;
            while (tokenizer.hasMoreTokens()) {
                String token = tokenizer.nextToken();
                ++tokenCounter;
                if (!token.equals("allDeadCode") && !token.equals("allDeprecation") && !token.equals("allJavadoc") && !token.equals("allOver-ann") && !token.equals("assertIdentifier") && !token.equals("boxing") && !token.equals("charConcat") && !token.equals("compareIdentical") && !token.equals("conditionAssign") && !token.equals("constructorName") && !token.equals("deadCode") && !token.equals("dep-ann") && !token.equals("deprecation") && !token.equals("discouraged") && !token.equals("emptyBlock") && !token.equals("enumIdentifier") && !token.equals("enumSwitch") && !token.equals("fallthrough") && !token.equals("fieldHiding") && !token.equals("finalBound") && !token.equals("finally") && !token.equals("forbidden") && !token.equals("hashCode") && !token.equals("hiding") && !token.equals("includeAssertNull") && !token.equals("incomplete-switch") && !token.equals("indirectStatic") && !token.equals("interfaceNonInherited") && !token.equals("intfAnnotation") && !token.equals("intfNonInherited") && !token.equals("intfRedundant") && !token.equals("javadoc") && !token.equals("localHiding") && !token.equals("maskedCatchBlock") && !token.equals("maskedCatchBlocks") && !token.equals("nls") && !token.equals("noEffectAssign") && !token.equals("noImplicitStringConversion") && !token.equals("null") && !token.equals("nullDereference") && !token.equals("over-ann") && !token.equals("packageDefaultMethod") && !token.equals("paramAssign") && !token.equals("pkgDefaultMethod") && !token.equals("raw") && !token.equals("semicolon") && !token.equals("serial") && !token.equals("specialParamHiding") && !token.equals("static-access") && !token.equals("staticReceiver") && !token.equals("super") && !token.equals("suppress") && !token.equals("syncOverride") && !token.equals("synthetic-access") && !token.equals("syntheticAccess") && !token.equals("typeHiding") && !token.equals("unchecked") && !token.equals("unnecessaryElse") && !token.equals("unnecessaryOperator") && !token.equals("unqualified-field-access") && !token.equals("unqualifiedField") && !token.equals("unsafe") && !token.equals("unused") && !token.equals("unusedArgument") && !token.equals("unusedArguments") && !token.equals("unusedImport") && !token.equals("unusedImports") && !token.equals("unusedLabel") && !token.equals("unusedLocal") && !token.equals("unusedLocals") && !token.equals("unusedPrivate") && !token.equals("unusedThrown") && !token.equals("unusedTypeArgs") && !token.equals("uselessTypeCheck") && !token.equals("varargsCast")) {
                    if (token.equals("warningToken")) {
                        continue;
                    }
                    if (token.equals("tasks")) {
                        String taskTags = "";
                        int start = token.indexOf(40);
                        int end = token.indexOf(41);
                        if (start >= 0 && end >= 0 && start < end) {
                            taskTags = token.substring(start + 1, end).trim();
                            taskTags = taskTags.replace('|', ',');
                        }
                        if (taskTags.length() == 0) {
                            return -1;
                        }
                        continue;
                    }
                    else {
                        return -1;
                    }
                }
                else {
                    continue;
                }
            }
            if (tokenCounter == 0) {
                return -1;
            }
            return 0;
        }
        else if (option.startsWith("-nowarn")) {
            switch (option.length()) {
                case 7: {
                    return 0;
                }
                case 8: {
                    return -1;
                }
                default: {
                    int foldersStart = option.indexOf(91) + 1;
                    int foldersEnd = option.lastIndexOf(93);
                    if (foldersStart <= 8 || foldersEnd == -1 || foldersStart > foldersEnd || foldersEnd < option.length() - 1) {
                        return -1;
                    }
                    String folders = option.substring(foldersStart, foldersEnd);
                    if (folders.length() > 0) {
                        return 0;
                    }
                    return -1;
                }
            }
        }
        else {
            if (option.startsWith("-J") || option.startsWith("-X") || option.startsWith("-A")) {
                return 0;
            }
            return -1;
        }
    }
}
